package com.junmp.jyzb.controller;

import com.junmp.jyzb.api.bean.dto.*;
import com.junmp.jyzb.api.bean.query.*;
import com.junmp.jyzb.api.bean.req.EquipmentBindReq;
import com.junmp.jyzb.entity.InventorySummary;
import com.junmp.jyzb.service.*;
import com.junmp.jyzb.utils.ResponseResult;
import com.junmp.v2.common.bean.request.ValidationApi;
import com.junmp.v2.common.bean.response.ApiRes;
import com.junmp.v2.db.api.page.PageResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@RestController
@Slf4j
@RequestMapping("/Inventory")
@Api(tags = "库存模块")
public class InventoryController {
    @Resource
    public InventoryService inventoryService;
    @Resource
    public InventorySummaryService inventorySummaryService;
    @Resource
    public MQProductService mqProductService;


    @GetMapping("/testMQ")
    @ApiOperation("根据组织机构查询库存信息")
    public ApiRes<Boolean> testMQ( ) {
        String aa="";
        return ApiRes.success(mqProductService.sendMessage());
    }
    //根据组织机构id/单警柜id/仓库id查询出库存的汇总信息
    @PostMapping("/GetEquipmentInfo")
    @ApiOperation("根据条件查询库存汇总信息")
    public ApiRes<PageResult<InventorySummary>> getEquipmentInfo(@RequestBody @Validated(ValidationApi.edit.class) InventorySumReq req) {
        return ApiRes.success(inventorySummaryService.getEquipmentInfo(req));
    }


    //填充汇总信息
    @PostMapping("/SetInventoryMsg")
    @ApiOperation("填充汇总表信息")
    public ApiRes<Boolean> setInventoryMsg() {
        boolean result = inventoryService.setInventoryMsg();
        if (!result){
            return ApiRes.failure("汇总失败");
        }
        return ApiRes.success(result);
    }

    @PostMapping("/getEquipmentInfo")
    @ApiOperation("查询库存明细信息")
    public ResponseResult getEquipmentInfo(@RequestBody Map<String, Object> msg) {
        ResponseResult returnMsg = inventoryService.getEquipmentInfo(msg);
        return  returnMsg;
    }


    @PostMapping("/EquipmentBind")
    @ApiOperation("装备绑定箱门")
    public ApiRes<Boolean> InventoryBind(@RequestBody @Validated(ValidationApi.edit.class) EquipmentBindReq req){
        return ApiRes.success(inventoryService.InventoryBind(req));
    }

    @PostMapping("/UpdateWarehouseInsNum")
    @ApiOperation("手动重置仓库库存数量信息")
    public ApiRes<Boolean> UpdateWarehouseInsNum(@RequestBody @Validated(ValidationApi.detail.class) WarehouseReq req){
        return ApiRes.success(inventoryService.UpdateWarehouseInsNum(req));
    }

    @PostMapping("/UpdateCabinetInsNum")
    @ApiOperation("手动重置单警柜库存数量信息")
    public ApiRes<Boolean> UpdateCabinetInsNum(@RequestBody @Validated(ValidationApi.detail.class)CabinetReq req){
        return ApiRes.success(inventoryService.UpdateCabinetInsNum(req));
    }

    @PostMapping("/GetInvInfoByEpc")
    @ApiOperation("根据EPC列表获取装备信息（简要）")
    public ApiRes<List<EqsBriefDto>> GetInvInfoByEpc(@RequestBody InventoryReq req){
        return ApiRes.success(inventoryService.GetInvInfoByEpc(req));
    }

    //通过组织机构id获取装备详情信息（不是装备汇总信息）
    @PostMapping("/GetInventoryByOrgId")
    @ApiOperation("查询组织机构拥有装备详情列表")
    public ApiRes<List<InventoryDto>> getInventoryByOrgId(@RequestBody @Validated(ValidationApi.detail.class) InventoryReq req){
        return ApiRes.success(inventoryService.getInventoryByOrgId(req));
    }

    //根据组织机构/单警柜id/仓库id查询每件装备细信的详息
    @PostMapping("/EqsBySearchType")
    @ApiOperation("根据传入信息查询装备信息")
    public ApiRes<List<InventoryDto>> EqsBySearchType(@RequestBody @Validated(ValidationApi.edit.class) InventoryReq req ){
        return ApiRes.success(inventoryService.EqsBySearchType(req));
    }


    //查询箱门 的装备汇总信息（传递cabinetBoxId）
    //查询单警柜下的装备信息汇总（传递cabinetId）

    //通过装备id获取该装备的详细信息

    //根据装备id查询出装备的详细信息
    @PostMapping("/GetDetail")
    @ApiOperation("根据装备id查询装备明细信息")
    public ApiRes<InventoryDto> getInventoryDetail(@RequestBody InventoryReq req) {
        return  ApiRes.success(inventoryService.getInventoryDetail(req));
    }

    //查询箱门（cabinetBox下）所有装备简要信息列表（传递cabinetBoxId）
    @PostMapping("/searchEqsByBoxId")
    @ApiOperation("查询某一箱门下的所有装备简要信息")
    public ApiRes<List<EqsBriefDto>> searchEqsByBoxId(@RequestBody @Validated(ValidationApi.detail.class) CabinetBoxReq req){
        return ApiRes.success(inventoryService.searchEqsByBoxId(req));
    }
    //查询单警柜下的汇总信息（通过单警柜id进行获取）
//    @PostMapping("/EqsByCabinetId")
//    @ApiOperation("查询单警柜下的汇总信息")
//    public ApiRes<List<EqsBriefDto>> EqsByCabinetId(){
//        return ApiRes.success(inventoryService.EqsByCabinetId());
//    }

    @PostMapping("/ShelfInventoryList")
    @ApiOperation("根据货架id查询装备信息汇总")
    public ApiRes<ShelfInventoryDto> ShelfInventoryList(@RequestBody @Validated(ValidationApi.edit.class) ShelfReq req){
        return ApiRes.success(inventoryService.ShelfInventoryList(req));
    }

    @PostMapping("/ShelfInventoryDetail")
    @ApiOperation(("/通过货架id查询每件装备信息简要"))
    public ApiRes<List<EqsBriefDto>> AreaInventoryDetail(@RequestBody @Validated(ValidationApi.edit.class) ShelfReq req){
        return ApiRes.success(inventoryService.ShelfInventoryDetail(req));
    }

    @PostMapping("/AreaInventoryList")
    @ApiOperation("根据区域id查询装备信息汇总")
    public ApiRes<AreaInventoryDto> AreaInventoryList(@RequestBody @Validated(ValidationApi.edit.class) WarehouseAreaReq req){
        return ApiRes.success(inventoryService.AreaInventoryList(req));
    }


}
